Documentation
¶
Overview ¶
Package server provides primitives to interact with the openapi HTTP API.
Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.6.1-0.20260318123712-00a90b7a03f4 DO NOT EDIT.
Index ¶
- func Handler(si ServerInterface) http.Handler
- func HandlerFromMux(si ServerInterface, r chi.Router) http.Handler
- func HandlerFromMuxWithBaseURL(si ServerInterface, r chi.Router, baseURL string) http.Handler
- func HandlerWithOptions(si ServerInterface, options ChiServerOptions) http.Handler
- type ChiServerOptions
- type CreateResource201JSONResponse
- type CreateResource400ApplicationProblemPlusJSONResponse
- type CreateResource406ApplicationProblemPlusJSONResponse
- type CreateResource409ApplicationProblemPlusJSONResponse
- type CreateResource422ApplicationProblemPlusJSONResponse
- type CreateResourceJSONRequestBody
- type CreateResourceParams
- type CreateResourceRequestObject
- type CreateResourceResponseObject
- type CreateResourcedefaultApplicationProblemPlusJSONResponse
- type DeleteResource204Response
- type DeleteResource400ApplicationProblemPlusJSONResponse
- type DeleteResource404ApplicationProblemPlusJSONResponse
- type DeleteResource422ApplicationProblemPlusJSONResponse
- type DeleteResourceRequestObject
- type DeleteResourceResponseObject
- type DeleteResourcedefaultApplicationProblemPlusJSONResponse
- type Error
- type GetHealth200JSONResponse
- type GetHealthRequestObject
- type GetHealthResponseObject
- type GetResource200JSONResponse
- type GetResource400ApplicationProblemPlusJSONResponse
- type GetResource404ApplicationProblemPlusJSONResponse
- type GetResourceRequestObject
- type GetResourceResponseObject
- type GetResourcedefaultApplicationProblemPlusJSONResponse
- type Health
- type InvalidParamFormatError
- type ListResources200JSONResponse
- type ListResources400ApplicationProblemPlusJSONResponse
- type ListResourcesParams
- type ListResourcesRequestObject
- type ListResourcesResponseObject
- type ListResourcesdefaultApplicationProblemPlusJSONResponse
- type MiddlewareFunc
- type RehydrateRequest
- type RehydrateResource200JSONResponse
- type RehydrateResource400ApplicationProblemPlusJSONResponse
- type RehydrateResource404ApplicationProblemPlusJSONResponse
- type RehydrateResource406ApplicationProblemPlusJSONResponse
- type RehydrateResource409ApplicationProblemPlusJSONResponse
- type RehydrateResource422ApplicationProblemPlusJSONResponse
- type RehydrateResourceJSONRequestBody
- type RehydrateResourceRequestObject
- type RehydrateResourceResponseObject
- type RehydrateResourcedefaultApplicationProblemPlusJSONResponse
- type RequiredHeaderError
- type RequiredParamError
- type Resource
- type ResourceIdPath
- type ResourceList
- type ServerInterface
- type ServerInterfaceWrapper
- func (siw *ServerInterfaceWrapper) CreateResource(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) DeleteResource(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetHealth(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) GetResource(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) ListResources(w http.ResponseWriter, r *http.Request)
- func (siw *ServerInterfaceWrapper) RehydrateResource(w http.ResponseWriter, r *http.Request)
- type StrictHTTPServerOptions
- type StrictHandlerFunc
- type StrictMiddlewareFunc
- type StrictServerInterface
- type TooManyValuesForParamError
- type UnescapedCookieParamError
- type Unimplemented
- func (_ Unimplemented) CreateResource(w http.ResponseWriter, r *http.Request, params CreateResourceParams)
- func (_ Unimplemented) DeleteResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
- func (_ Unimplemented) GetHealth(w http.ResponseWriter, r *http.Request)
- func (_ Unimplemented) GetResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
- func (_ Unimplemented) ListResources(w http.ResponseWriter, r *http.Request, params ListResourcesParams)
- func (_ Unimplemented) RehydrateResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
- type UnmarshalingParamError
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Handler ¶
func Handler(si ServerInterface) http.Handler
Handler creates http.Handler with routing matching OpenAPI spec.
func HandlerFromMux ¶
func HandlerFromMux(si ServerInterface, r chi.Router) http.Handler
HandlerFromMux creates http.Handler with routing matching OpenAPI spec based on the provided mux.
func HandlerWithOptions ¶
func HandlerWithOptions(si ServerInterface, options ChiServerOptions) http.Handler
HandlerWithOptions creates http.Handler with additional options
Types ¶
type ChiServerOptions ¶
type ChiServerOptions struct {
BaseURL string
BaseRouter chi.Router
Middlewares []MiddlewareFunc
ErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
}
type CreateResource201JSONResponse ¶
type CreateResource201JSONResponse Resource
func (CreateResource201JSONResponse) VisitCreateResourceResponse ¶
func (response CreateResource201JSONResponse) VisitCreateResourceResponse(w http.ResponseWriter) error
type CreateResource400ApplicationProblemPlusJSONResponse ¶
type CreateResource400ApplicationProblemPlusJSONResponse Error
func (CreateResource400ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse ¶
func (response CreateResource400ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse(w http.ResponseWriter) error
type CreateResource406ApplicationProblemPlusJSONResponse ¶
type CreateResource406ApplicationProblemPlusJSONResponse Error
func (CreateResource406ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse ¶
func (response CreateResource406ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse(w http.ResponseWriter) error
type CreateResource409ApplicationProblemPlusJSONResponse ¶
type CreateResource409ApplicationProblemPlusJSONResponse Error
func (CreateResource409ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse ¶
func (response CreateResource409ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse(w http.ResponseWriter) error
type CreateResource422ApplicationProblemPlusJSONResponse ¶
type CreateResource422ApplicationProblemPlusJSONResponse Error
func (CreateResource422ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse ¶
func (response CreateResource422ApplicationProblemPlusJSONResponse) VisitCreateResourceResponse(w http.ResponseWriter) error
type CreateResourceJSONRequestBody ¶
type CreateResourceJSONRequestBody = Resource
CreateResourceJSONRequestBody defines body for CreateResource for application/json ContentType.
type CreateResourceParams ¶
type CreateResourceParams struct {
// Id Optional ID for the resource
Id *string `form:"id,omitempty" json:"id,omitempty"`
}
CreateResourceParams defines parameters for CreateResource.
type CreateResourceRequestObject ¶
type CreateResourceRequestObject struct {
Params CreateResourceParams
Body *CreateResourceJSONRequestBody
}
type CreateResourceResponseObject ¶
type CreateResourceResponseObject interface {
VisitCreateResourceResponse(w http.ResponseWriter) error
}
type CreateResourcedefaultApplicationProblemPlusJSONResponse ¶
func (CreateResourcedefaultApplicationProblemPlusJSONResponse) VisitCreateResourceResponse ¶
func (response CreateResourcedefaultApplicationProblemPlusJSONResponse) VisitCreateResourceResponse(w http.ResponseWriter) error
type DeleteResource204Response ¶
type DeleteResource204Response struct {
}
func (DeleteResource204Response) VisitDeleteResourceResponse ¶
func (response DeleteResource204Response) VisitDeleteResourceResponse(w http.ResponseWriter) error
type DeleteResource400ApplicationProblemPlusJSONResponse ¶
type DeleteResource400ApplicationProblemPlusJSONResponse Error
func (DeleteResource400ApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse ¶
func (response DeleteResource400ApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse(w http.ResponseWriter) error
type DeleteResource404ApplicationProblemPlusJSONResponse ¶
type DeleteResource404ApplicationProblemPlusJSONResponse Error
func (DeleteResource404ApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse ¶
func (response DeleteResource404ApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse(w http.ResponseWriter) error
type DeleteResource422ApplicationProblemPlusJSONResponse ¶
type DeleteResource422ApplicationProblemPlusJSONResponse Error
func (DeleteResource422ApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse ¶
func (response DeleteResource422ApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse(w http.ResponseWriter) error
type DeleteResourceRequestObject ¶
type DeleteResourceRequestObject struct {
ResourceId ResourceIdPath `json:"resourceId"`
}
type DeleteResourceResponseObject ¶
type DeleteResourceResponseObject interface {
VisitDeleteResourceResponse(w http.ResponseWriter) error
}
type DeleteResourcedefaultApplicationProblemPlusJSONResponse ¶
func (DeleteResourcedefaultApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse ¶
func (response DeleteResourcedefaultApplicationProblemPlusJSONResponse) VisitDeleteResourceResponse(w http.ResponseWriter) error
type Error ¶
type Error struct {
// Detail Human-readable explanation specific to this occurrence
Detail *string `json:"detail,omitempty"`
// Instance URI reference for this specific error occurrence
Instance *string `json:"instance,omitempty"`
// Status HTTP status code
Status *int `json:"status,omitempty"`
// Title Short human-readable summary of the problem
Title string `json:"title"`
// Type URI reference identifying the error type
Type string `json:"type"`
}
Error RFC 7807 compliant error response
type GetHealth200JSONResponse ¶
type GetHealth200JSONResponse Health
func (GetHealth200JSONResponse) VisitGetHealthResponse ¶
func (response GetHealth200JSONResponse) VisitGetHealthResponse(w http.ResponseWriter) error
type GetHealthRequestObject ¶
type GetHealthRequestObject struct {
}
type GetHealthResponseObject ¶
type GetHealthResponseObject interface {
VisitGetHealthResponse(w http.ResponseWriter) error
}
type GetResource200JSONResponse ¶
type GetResource200JSONResponse Resource
func (GetResource200JSONResponse) VisitGetResourceResponse ¶
func (response GetResource200JSONResponse) VisitGetResourceResponse(w http.ResponseWriter) error
type GetResource400ApplicationProblemPlusJSONResponse ¶
type GetResource400ApplicationProblemPlusJSONResponse Error
func (GetResource400ApplicationProblemPlusJSONResponse) VisitGetResourceResponse ¶
func (response GetResource400ApplicationProblemPlusJSONResponse) VisitGetResourceResponse(w http.ResponseWriter) error
type GetResource404ApplicationProblemPlusJSONResponse ¶
type GetResource404ApplicationProblemPlusJSONResponse Error
func (GetResource404ApplicationProblemPlusJSONResponse) VisitGetResourceResponse ¶
func (response GetResource404ApplicationProblemPlusJSONResponse) VisitGetResourceResponse(w http.ResponseWriter) error
type GetResourceRequestObject ¶
type GetResourceRequestObject struct {
ResourceId ResourceIdPath `json:"resourceId"`
}
type GetResourceResponseObject ¶
type GetResourceResponseObject interface {
VisitGetResourceResponse(w http.ResponseWriter) error
}
type GetResourcedefaultApplicationProblemPlusJSONResponse ¶
func (GetResourcedefaultApplicationProblemPlusJSONResponse) VisitGetResourceResponse ¶
func (response GetResourcedefaultApplicationProblemPlusJSONResponse) VisitGetResourceResponse(w http.ResponseWriter) error
type Health ¶
type Health struct {
// Path Canonical path of the resource
Path *string `json:"path,omitempty"`
// Status Health status
Status string `json:"status"`
}
Health Health status singleton resource
type InvalidParamFormatError ¶
func (*InvalidParamFormatError) Error ¶
func (e *InvalidParamFormatError) Error() string
func (*InvalidParamFormatError) Unwrap ¶
func (e *InvalidParamFormatError) Unwrap() error
type ListResources200JSONResponse ¶
type ListResources200JSONResponse ResourceList
func (ListResources200JSONResponse) VisitListResourcesResponse ¶
func (response ListResources200JSONResponse) VisitListResourcesResponse(w http.ResponseWriter) error
type ListResources400ApplicationProblemPlusJSONResponse ¶
type ListResources400ApplicationProblemPlusJSONResponse Error
func (ListResources400ApplicationProblemPlusJSONResponse) VisitListResourcesResponse ¶
func (response ListResources400ApplicationProblemPlusJSONResponse) VisitListResourcesResponse(w http.ResponseWriter) error
type ListResourcesParams ¶
type ListResourcesParams struct {
// Provider Filter provider name
Provider *string `form:"provider,omitempty" json:"provider,omitempty"`
// MaxPageSize Maximum number of results per page
MaxPageSize *int `form:"max_page_size,omitempty" json:"max_page_size,omitempty"`
// PageToken Token for pagination
PageToken *string `form:"page_token,omitempty" json:"page_token,omitempty"`
}
ListResourcesParams defines parameters for ListResources.
type ListResourcesRequestObject ¶
type ListResourcesRequestObject struct {
Params ListResourcesParams
}
type ListResourcesResponseObject ¶
type ListResourcesResponseObject interface {
VisitListResourcesResponse(w http.ResponseWriter) error
}
type ListResourcesdefaultApplicationProblemPlusJSONResponse ¶
func (ListResourcesdefaultApplicationProblemPlusJSONResponse) VisitListResourcesResponse ¶
func (response ListResourcesdefaultApplicationProblemPlusJSONResponse) VisitListResourcesResponse(w http.ResponseWriter) error
type RehydrateRequest ¶
type RehydrateRequest struct {
// NewResourceId The new resource ID to use for the rehydrated resource
NewResourceId string `json:"new_resource_id"`
}
RehydrateRequest Request body for resource rehydration
type RehydrateResource200JSONResponse ¶
type RehydrateResource200JSONResponse Resource
func (RehydrateResource200JSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResource200JSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RehydrateResource400ApplicationProblemPlusJSONResponse ¶
type RehydrateResource400ApplicationProblemPlusJSONResponse Error
func (RehydrateResource400ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResource400ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RehydrateResource404ApplicationProblemPlusJSONResponse ¶
type RehydrateResource404ApplicationProblemPlusJSONResponse Error
func (RehydrateResource404ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResource404ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RehydrateResource406ApplicationProblemPlusJSONResponse ¶
type RehydrateResource406ApplicationProblemPlusJSONResponse Error
func (RehydrateResource406ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResource406ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RehydrateResource409ApplicationProblemPlusJSONResponse ¶
type RehydrateResource409ApplicationProblemPlusJSONResponse Error
func (RehydrateResource409ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResource409ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RehydrateResource422ApplicationProblemPlusJSONResponse ¶
type RehydrateResource422ApplicationProblemPlusJSONResponse Error
func (RehydrateResource422ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResource422ApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RehydrateResourceJSONRequestBody ¶
type RehydrateResourceJSONRequestBody = RehydrateRequest
RehydrateResourceJSONRequestBody defines body for RehydrateResource for application/json ContentType.
type RehydrateResourceRequestObject ¶
type RehydrateResourceRequestObject struct {
ResourceId ResourceIdPath `json:"resourceId"`
Body *RehydrateResourceJSONRequestBody
}
type RehydrateResourceResponseObject ¶
type RehydrateResourceResponseObject interface {
VisitRehydrateResourceResponse(w http.ResponseWriter) error
}
type RehydrateResourcedefaultApplicationProblemPlusJSONResponse ¶
type RehydrateResourcedefaultApplicationProblemPlusJSONResponse struct {
Body Error
StatusCode int
}
func (RehydrateResourcedefaultApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse ¶
func (response RehydrateResourcedefaultApplicationProblemPlusJSONResponse) VisitRehydrateResourceResponse(w http.ResponseWriter) error
type RequiredHeaderError ¶
func (*RequiredHeaderError) Error ¶
func (e *RequiredHeaderError) Error() string
func (*RequiredHeaderError) Unwrap ¶
func (e *RequiredHeaderError) Unwrap() error
type RequiredParamError ¶
type RequiredParamError struct {
ParamName string
}
func (*RequiredParamError) Error ¶
func (e *RequiredParamError) Error() string
type Resource ¶
type Resource struct {
// ApprovalStatus The approval status after the spec is validated by Policy Engine.
ApprovalStatus *string `json:"approval_status,omitempty"`
// CatalogItemInstanceId The unique identifier of the catalog item instance
CatalogItemInstanceId string `json:"catalog_item_instance_id"`
// CreateTime Timestamp when the resource was first created
CreateTime *time.Time `json:"create_time,omitempty"`
// Id Unique identifier for the Resource
Id *string `json:"id,omitempty"`
// Path Resource path identifier
Path *string `json:"path,omitempty"`
// ProviderName Name of the Service Provider
ProviderName *string `json:"provider_name,omitempty"`
// Spec Service specification following one of the supported service type
// schemas (VMSpec, ContainerSpec, DatabaseSpec, or ClusterSpec).
Spec map[string]interface{} `json:"spec"`
// UpdateTime Timestamp when the resource was last updated
UpdateTime *time.Time `json:"update_time,omitempty"`
}
Resource Full resource representation
type ResourceList ¶
type ResourceList struct {
// NextPageToken Token for retrieving the next page of results
NextPageToken *string `json:"next_page_token,omitempty"`
Resources []Resource `json:"resources"`
}
ResourceList Paginated list of resources
type ServerInterface ¶
type ServerInterface interface {
// Health check
// (GET /health)
GetHealth(w http.ResponseWriter, r *http.Request)
// List all resources
// (GET /resources)
ListResources(w http.ResponseWriter, r *http.Request, params ListResourcesParams)
// Create a resource
// (POST /resources)
CreateResource(w http.ResponseWriter, r *http.Request, params CreateResourceParams)
// Delete a single resource
// (DELETE /resources/{resourceId})
DeleteResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
// Get a single resource
// (GET /resources/{resourceId})
GetResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
// Rehydrate a resource
// (POST /resources/{resourceId}:rehydrate)
RehydrateResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
}
ServerInterface represents all server handlers.
func NewStrictHandler ¶
func NewStrictHandler(ssi StrictServerInterface, middlewares []StrictMiddlewareFunc) ServerInterface
func NewStrictHandlerWithOptions ¶
func NewStrictHandlerWithOptions(ssi StrictServerInterface, middlewares []StrictMiddlewareFunc, options StrictHTTPServerOptions) ServerInterface
type ServerInterfaceWrapper ¶
type ServerInterfaceWrapper struct {
Handler ServerInterface
HandlerMiddlewares []MiddlewareFunc
ErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
}
ServerInterfaceWrapper converts contexts to parameters.
func (*ServerInterfaceWrapper) CreateResource ¶
func (siw *ServerInterfaceWrapper) CreateResource(w http.ResponseWriter, r *http.Request)
CreateResource operation middleware
func (*ServerInterfaceWrapper) DeleteResource ¶
func (siw *ServerInterfaceWrapper) DeleteResource(w http.ResponseWriter, r *http.Request)
DeleteResource operation middleware
func (*ServerInterfaceWrapper) GetHealth ¶
func (siw *ServerInterfaceWrapper) GetHealth(w http.ResponseWriter, r *http.Request)
GetHealth operation middleware
func (*ServerInterfaceWrapper) GetResource ¶
func (siw *ServerInterfaceWrapper) GetResource(w http.ResponseWriter, r *http.Request)
GetResource operation middleware
func (*ServerInterfaceWrapper) ListResources ¶
func (siw *ServerInterfaceWrapper) ListResources(w http.ResponseWriter, r *http.Request)
ListResources operation middleware
func (*ServerInterfaceWrapper) RehydrateResource ¶
func (siw *ServerInterfaceWrapper) RehydrateResource(w http.ResponseWriter, r *http.Request)
RehydrateResource operation middleware
type StrictHTTPServerOptions ¶
type StrictHTTPServerOptions struct {
RequestErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
ResponseErrorHandlerFunc func(w http.ResponseWriter, r *http.Request, err error)
}
type StrictHandlerFunc ¶
type StrictHandlerFunc = strictnethttp.StrictHTTPHandlerFunc
type StrictMiddlewareFunc ¶
type StrictMiddlewareFunc = strictnethttp.StrictHTTPMiddlewareFunc
type StrictServerInterface ¶
type StrictServerInterface interface {
// Health check
// (GET /health)
GetHealth(ctx context.Context, request GetHealthRequestObject) (GetHealthResponseObject, error)
// List all resources
// (GET /resources)
ListResources(ctx context.Context, request ListResourcesRequestObject) (ListResourcesResponseObject, error)
// Create a resource
// (POST /resources)
CreateResource(ctx context.Context, request CreateResourceRequestObject) (CreateResourceResponseObject, error)
// Delete a single resource
// (DELETE /resources/{resourceId})
DeleteResource(ctx context.Context, request DeleteResourceRequestObject) (DeleteResourceResponseObject, error)
// Get a single resource
// (GET /resources/{resourceId})
GetResource(ctx context.Context, request GetResourceRequestObject) (GetResourceResponseObject, error)
// Rehydrate a resource
// (POST /resources/{resourceId}:rehydrate)
RehydrateResource(ctx context.Context, request RehydrateResourceRequestObject) (RehydrateResourceResponseObject, error)
}
StrictServerInterface represents all server handlers.
type TooManyValuesForParamError ¶
func (*TooManyValuesForParamError) Error ¶
func (e *TooManyValuesForParamError) Error() string
type UnescapedCookieParamError ¶
func (*UnescapedCookieParamError) Error ¶
func (e *UnescapedCookieParamError) Error() string
func (*UnescapedCookieParamError) Unwrap ¶
func (e *UnescapedCookieParamError) Unwrap() error
type Unimplemented ¶
type Unimplemented struct{}
func (Unimplemented) CreateResource ¶
func (_ Unimplemented) CreateResource(w http.ResponseWriter, r *http.Request, params CreateResourceParams)
Create a resource (POST /resources)
func (Unimplemented) DeleteResource ¶
func (_ Unimplemented) DeleteResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
Delete a single resource (DELETE /resources/{resourceId})
func (Unimplemented) GetHealth ¶
func (_ Unimplemented) GetHealth(w http.ResponseWriter, r *http.Request)
Health check (GET /health)
func (Unimplemented) GetResource ¶
func (_ Unimplemented) GetResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
Get a single resource (GET /resources/{resourceId})
func (Unimplemented) ListResources ¶
func (_ Unimplemented) ListResources(w http.ResponseWriter, r *http.Request, params ListResourcesParams)
List all resources (GET /resources)
func (Unimplemented) RehydrateResource ¶
func (_ Unimplemented) RehydrateResource(w http.ResponseWriter, r *http.Request, resourceId ResourceIdPath)
Rehydrate a resource (POST /resources/{resourceId}:rehydrate)
type UnmarshalingParamError ¶
func (*UnmarshalingParamError) Error ¶
func (e *UnmarshalingParamError) Error() string
func (*UnmarshalingParamError) Unwrap ¶
func (e *UnmarshalingParamError) Unwrap() error